==> limitorderv2-sdk-0.1.38.tgz: package/src/order.ts <==
import { validateAndParseAddress } from './utils';
import { TokenAmount, Price, ChainId, Token } from '@sushiswap/sdk'
import { getSignatureWithProvider, getSignature, Message, getTypedData, getTypeHash } from './entities/eip712'
import { LAMBDA_URL } from './constants';
import { ethers } from 'ethers';
import axios from "axios";

export interface ILimitOrderData {
    maker: string;
    tokenIn: string;
    tokenOut: string;
    tokenInDecimals: number;
    tokenOutDecimals: number;
    amountIn: string;
    amountOut: string;
    recipient: string;
    startTime: number;
    endTime: number;
    stopPrice: string;
    oracleAddress: string;
    oracleData: string;
    v: number;
    r: string;
    s: string;
    chainId: ChainId;
}

export class LimitOrder {

    public readonly maker: string;
    public readonly amountIn: TokenAmount;
    public readonly amountOut: TokenAmount;
    public readonly recipient: string;
    public readonly startTime: number;
    public readonly endTime: number;
    public readonly stopPrice: string;
    public readonly oracleAddress: string;
    public readonly oracleData: string;
    public v: number;
    public r: string;
    public s: string;

    static getLimitOrder(data: ILimitOrderData): LimitOrder {
        return new LimitOrder(
            data.maker,
            new TokenAmount(new Token(data.chainId, data.tokenIn, data.tokenInDecimals), data.amountIn),
            new TokenAmount(new Token(data.chainId, data.tokenOut, data.tokenOutDecimals), data.amountOut),
            data.recipient,
            data.startTime,
            data.endTime,
            data.stopPrice,
            data.oracleAddress,
            data.oracleData,
            data.v,
            data.r,
            data.s
        );
    }

    constructor(
        maker: string,
        amountIn: TokenAmount,
        amountOut: TokenAmount,
        recipient: string,
        startTime: number,
        endTime: number,
        stopPrice: string,
        oracleAddress: string,
        oracleData: string,
        v = 0,
        r = "",
        s = ""
    ) { 
        this.maker = validateAndParseAddress(maker);
        this.amountIn = amountIn;
        this.amountOut = amountOut;
        this.recipient = validateAndParseAddress(recipient);
        this.startTime = startTime;
        this.endTime = endTime;
        this.stopPrice = stopPrice;
        this.oracleAddress = validateAndParseAddress(oracleAddress);
        this.oracleData = oracleData;
        this.v = v;
        this.r = r;
        this.s = s;
    }

    get amountInRaw(): string {
        return this.amountIn.raw.toString();
    }

    get amountOutRaw(): string {
        return this.amountOut.raw.toString();
    }

    get tokenInAddress(): string {
        return this.amountIn.token.address;
    }

    get tokenOutAddress(): string {
        return this.amountOut.token.address;
    }

    get tokenInDecimals(): number {
        return this.amountIn.token.decimals;
    }

    get tokenOutDecimals(): number {
        return this.amountOut.token.decimals;
    }

    get chainId(): ChainId {
        return this.amountIn.token.chainId;
    }

    usePrice(price: Price): LimitOrder {
        return new LimitOrder(
            this.maker,
            this.amountIn,
            new TokenAmount(this.amountOut.token, price.quote(this.amountIn).raw.toString()),
            this.recipient,
            this.startTime,
            this.endTime,
            this.stopPrice,
            this.oracleAddress,
            this.oracleData
        );
    }

    signdOrderWithPrivatekey(chainId: ChainId, privateKey: string) {
        let order : Message = {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient: this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress : this.oracleAddress,
            oracleData: ethers.utils.keccak256(this.oracleData)
        }

        const { v, r, s } = getSignature(order, chainId, privateKey);

        this.v = v;
        this.r = r;
        this.s = s;

        return { v, r, s }
    }

    async signOrderWithProvider(chainId: ChainId, provider: ethers.providers.Web3Provider) {
        let order: Message = {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient: this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress: this.oracleAddress,
            oracleData: ethers.utils.keccak256(this.oracleData)
        }

        const { v, r, s } = await getSignatureWithProvider(order, chainId, provider);

        this.v = v;
        this.r = r;
        this.s = s;

        return { v, r, s }
    }

    getTypedData() {

        let order : Message = {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient : this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress : this.oracleAddress,
            oracleData: ethers.utils.keccak256(this.oracleData)
        }

        return getTypedData(order, this.chainId);
    }

    getTypeHash() {
        let typedData = this.getTypedData();
        let digest = getTypeHash(typedData);
        return digest;
    }

    async send() {
        const resp = await axios.post(`${LAMBDA_URL}/orders/create`, {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            tokenInDecimals: this.tokenInDecimals,
            tokenOutDecimals: this.tokenOutDecimals,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient: this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress: this.oracleAddress,
            oracleData: this.oracleData,
            v: this.v,
            r: this.r,
            s: this.s,
            chainId: this.amountIn.token.chainId
        });

        return resp.data;
    }
}

==> limitorderv2-sdk-0.1.42.tgz: package/src/order.ts <==
import { validateAndParseAddress } from './utils';
import { TokenAmount, Price, ChainId, Token } from '@sushiswap/sdk'
import { getSignatureWithProvider, getSignature, Message, getTypedData, getTypeHash } from './entities/eip712'
import { LAMBDA_URL } from './constants';
import { ethers } from 'ethers';
import axios from "axios";

export interface ILimitOrderData {
    maker: string;
    tokenIn: string;
    tokenOut: string;
    tokenInDecimals: number;
    tokenOutDecimals: number;
    tokenInSymbol: string;
    tokenOutSymbol: string;
    amountIn: string;
    amountOut: string;
    recipient: string;
    startTime: number;
    endTime: number;
    stopPrice: string;
    oracleAddress: string;
    oracleData: string;
    v: number;
    r: string;
    s: string;
    chainId: ChainId;
}

export class LimitOrder {

    public readonly maker: string;
    public readonly amountIn: TokenAmount;
    public readonly amountOut: TokenAmount;
    public readonly recipient: string;
    public readonly startTime: number;
    public readonly endTime: number;
    public readonly stopPrice: string;
    public readonly oracleAddress: string;
    public readonly oracleData: string;
    public v: number;
    public r: string;
    public s: string;

    static getLimitOrder(data: ILimitOrderData): LimitOrder {
        return new LimitOrder(
            data.maker,
            new TokenAmount(new Token(data.chainId, data.tokenIn, data.tokenInDecimals, data.tokenInSymbol), data.amountIn),
            new TokenAmount(new Token(data.chainId, data.tokenOut, data.tokenOutDecimals, data.tokenOutSymbol), data.amountOut),
            data.recipient,
            data.startTime,
            data.endTime,
            data.stopPrice,
            data.oracleAddress,
            data.oracleData,
            data.v,
            data.r,
            data.s
        );
    }

    constructor(
        maker: string,
        amountIn: TokenAmount,
        amountOut: TokenAmount,
        recipient: string,
        startTime: number,
        endTime: number,
        stopPrice: string,
        oracleAddress: string,
        oracleData: string,
        v = 0,
        r = "",
        s = ""
    ) { 
        this.maker = validateAndParseAddress(maker);
        this.amountIn = amountIn;
        this.amountOut = amountOut;
        this.recipient = validateAndParseAddress(recipient);
        this.startTime = startTime;
        this.endTime = endTime;
        this.stopPrice = stopPrice;
        this.oracleAddress = validateAndParseAddress(oracleAddress);
        this.oracleData = oracleData;
        this.v = v;
        this.r = r;
        this.s = s;
    }

    get amountInRaw(): string {
        return this.amountIn.raw.toString();
    }

    get amountOutRaw(): string {
        return this.amountOut.raw.toString();
    }

    get tokenInAddress(): string {
        return this.amountIn.token.address;
    }

    get tokenOutAddress(): string {
        return this.amountOut.token.address;
    }

    get tokenInDecimals(): number {
        return this.amountIn.token.decimals;
    }

    get tokenOutDecimals(): number {
        return this.amountOut.token.decimals;
    }

    get tokenInSymbol(): string {
        return this.amountIn.token.symbol || '';
    }

    get tokenOutSymbol(): string {
        return this.amountOut.token.symbol || '';
    }

    get chainId(): ChainId {
        return this.amountIn.token.chainId;
    }

    usePrice(price: Price): LimitOrder {
        return new LimitOrder(
            this.maker,
            this.amountIn,
            new TokenAmount(this.amountOut.token, price.quote(this.amountIn).raw.toString()),
            this.recipient,
            this.startTime,
            this.endTime,
            this.stopPrice,
            this.oracleAddress,
            this.oracleData
        );
    }

    signdOrderWithPrivatekey(chainId: ChainId, privateKey: string) {
        let order : Message = {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient: this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress : this.oracleAddress,
            oracleData: ethers.utils.keccak256(this.oracleData)
        }

        const { v, r, s } = getSignature(order, chainId, privateKey);

        this.v = v;
        this.r = r;
        this.s = s;

        return { v, r, s }
    }

    async signOrderWithProvider(chainId: ChainId, provider: ethers.providers.Web3Provider) {
        let order: Message = {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient: this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress: this.oracleAddress,
            oracleData: ethers.utils.keccak256(this.oracleData)
        }

        const { v, r, s } = await getSignatureWithProvider(order, chainId, provider);

        this.v = v;
        this.r = r;
        this.s = s;

        return { v, r, s }
    }

    getTypedData() {

        let order : Message = {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient : this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress : this.oracleAddress,
            oracleData: ethers.utils.keccak256(this.oracleData)
        }

        return getTypedData(order, this.chainId);
    }

    getTypeHash() {
        let typedData = this.getTypedData();
        let digest = getTypeHash(typedData);
        return digest;
    }

    async send() {
        const resp = await axios.post(`${LAMBDA_URL}/orders/create`, {
            maker: this.maker,
            tokenIn: this.tokenInAddress,
            tokenOut: this.tokenOutAddress,
            tokenInDecimals: this.tokenInDecimals,
            tokenOutDecimals: this.tokenOutDecimals,
            tokenInSymbol: this.tokenInSymbol,
            tokenOutSymbol: this.tokenOutSymbol,
            amountIn: this.amountInRaw,
            amountOut: this.amountOutRaw,
            recipient: this.recipient,
            startTime: this.startTime,
            endTime: this.endTime,
            stopPrice: this.stopPrice,
            oracleAddress: this.oracleAddress,
            oracleData: this.oracleData,
            v: this.v,
            r: this.r,
            s: this.s,
            chainId: this.amountIn.token.chainId
        });

        return resp.data;
    }
}
